@@ -1,4 +1,4 @@
-#
+
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -11,13 +11,23 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import sqlalchemy
+from heat.db.sqlalchemy.types import LongText
+from heat.db.sqlalchemy.types import Json
 
-from heat.db.sqlalchemy import types
+import sqlalchemy
 
 
 def upgrade(migrate_engine):
     meta = sqlalchemy.MetaData(bind=migrate_engine)
     software_config = sqlalchemy.Table('software_config', meta, autoload=True)
-    software_config.c.config.alter(type=types.Json)
+    software_config.c.config.alter(type=Json)
     software_config.c.io.drop()
+
+
+def downgrade(migrate_engine):
+    meta = sqlalchemy.MetaData(bind=migrate_engine)
+    software_config = sqlalchemy.Table('software_config', meta, autoload=True)
+    software_config.c.config.alter(type=LongText)
+
+    io = sqlalchemy.Column('io', Json)
+    io.create(software_config)
